@@ -1,12 +1,15 @@
 #This file is part of Tryton.  The COPYRIGHT file at the top level of
 #this repository contains the full copyright notices and license terms.
 from trytond.model import ModelView, ModelSQL, fields
-from trytond.pyson import Not, Bool, Eval
+from trytond.pyson import Eval
 from trytond.transaction import Transaction
+from trytond.pool import Pool
+from trytond.backend import TableHandler
 
 STATES = {
-    'readonly': Not(Bool(Eval('active'))),
-}
+    'readonly': ~Eval('active', True),
+    }
+DEPENDS = ['active']
 
 
 class Template(ModelSQL, ModelView):
@@ -15,47 +18,87 @@ class Template(ModelSQL, ModelView):
     _description = __doc__
 
     name = fields.Char('Name', size=None, required=True, translate=True,
-            select=1, states=STATES)
+        select=True, states=STATES, depends=DEPENDS)
     type = fields.Selection([
-        ('stockable', 'Stockable'),
-        ('consumable', 'Consumable'),
-        ('service', 'Service')
-        ], 'Type', required=True, states=STATES)
-    category = fields.Many2One('product.category', 'Category', required=True,
-            states=STATES)
+            ('goods', 'Goods'),
+            ('assets', 'Assets'),
+            ('service', 'Service')
+            ], 'Type', required=True, states=STATES, depends=DEPENDS)
+    consumable = fields.Boolean('Consumable',
+        states={
+            'readonly': ~Eval('active', True),
+            'invisible': Eval('type', 'goods') != 'goods',
+            },
+        depends=['active', 'type'])
+    category = fields.Many2One('product.category', 'Category',
+        states=STATES, depends=DEPENDS)
     list_price = fields.Property(fields.Numeric('List Price', states=STATES,
-        digits=(16, 4)))
+            digits=(16, 4), depends=DEPENDS, required=True))
     list_price_uom = fields.Function(fields.Numeric('List Price',
         digits=(16, 4)), 'get_price_uom')
     cost_price = fields.Property(fields.Numeric('Cost Price',
-            states=STATES, digits=(16, 4)))
+            states=STATES, digits=(16, 4), depends=DEPENDS, required=True))
     cost_price_uom = fields.Function(fields.Numeric('Cost Price',
         digits=(16, 4)), 'get_price_uom')
     cost_price_method = fields.Property(fields.Selection([
-        ("fixed", "Fixed"),
-        ("average", "Average")
-        ], 'Cost Method', required=True, states=STATES))
+                ("fixed", "Fixed"),
+                ("average", "Average")
+                ], 'Cost Method', required=True, states=STATES,
+            depends=DEPENDS))
     default_uom = fields.Many2One('product.uom', 'Default UOM', required=True,
-            states=STATES)
-    active = fields.Boolean('Active', select=1)
+        states=STATES, depends=DEPENDS)
+    default_uom_category = fields.Function(
+        fields.Many2One('product.uom.category', 'Default UOM Category',
+            on_change_with=['default_uom']),
+        'get_default_uom_category')
+    active = fields.Boolean('Active', select=True)
     products = fields.One2Many('product.product', 'template', 'Products',
-            states=STATES)
+        states=STATES, depends=DEPENDS)
+
+    def init(self, module_name):
+        cursor = Transaction().cursor
+
+        super(Template, self).init(module_name)
+
+        table = TableHandler(cursor, self, module_name)
+        # Migration from 2.2: category is no more required
+        table.not_null_action('category', 'remove')
+
+        # Migration from 2.2: new types
+        cursor.execute('UPDATE "' + self._table + '" '
+            'SET consumable = %s WHERE type = %s', (True, 'consumable'))
+        cursor.execute('UPDATE "' + self._table + '" '
+            'SET type = %s WHERE type IN (%s, %s)',
+            ('goods', 'stockable', 'consumable'))
 
     def default_active(self):
         return True
 
     def default_type(self):
-        return 'stockable'
+        return 'goods'
 
     def default_cost_price_method(self):
         return 'fixed'
 
+    def on_change_with_default_uom_category(self, values):
+        pool = Pool()
+        uom_obj = pool.get('product.uom')
+        if values.get('default_uom'):
+            uom = uom_obj.browse(values['default_uom'])
+            return uom.category.id
+
+    def get_default_uom_category(self, ids, name):
+        categories = {}
+        for template in self.browse(ids):
+            categories[template.id] = template.default_uom.category.id
+        return categories
+
     def get_price_uom(self, ids, name):
-        product_uom_obj = self.pool.get('product.uom')
+        product_uom_obj = Pool().get('product.uom')
         res = {}
         field = name[:-4]
         if Transaction().context.get('uom'):
-            to_uom = self.pool.get('product.uom').browse(
+            to_uom = product_uom_obj.browse(
                 Transaction().context['uom'])
             for product in self.browse(ids):
                 res[product.id] = product_uom_obj.compute_price(
@@ -69,7 +112,7 @@ class Template(ModelSQL, ModelView):
         if default is None:
             default = {}
         default = default.copy()
-        default['products'] = False
+        default['products'] = None
         return super(Template, self).copy(ids, default=default)
 
 Template()
@@ -82,8 +125,8 @@ class Product(ModelSQL, ModelView):
     _inherits = {'product.template': 'template'}
 
     template = fields.Many2One('product.template', 'Product Template',
-            required=True, ondelete='CASCADE', select=1)
-    code = fields.Char("Code", size=None, select=1)
+            required=True, ondelete='CASCADE', select=True)
+    code = fields.Char("Code", size=None, select=True)
     description = fields.Text("Description", translate=True)
 
     def get_rec_name(self, ids, name):
@@ -105,7 +148,7 @@ class Product(ModelSQL, ModelView):
         return [('name',) + clause[1:]]
 
     def delete(self, ids):
-        template_obj = self.pool.get('product.template')
+        template_obj = Pool().get('product.template')
 
         if isinstance(ids, (int, long)):
             ids = [ids]
@@ -126,7 +169,7 @@ class Product(ModelSQL, ModelView):
         return res
 
     def copy(self, ids, default=None):
-        template_obj = self.pool.get('product.template')
+        template_obj = Pool().get('product.template')
 
         int_id = False
         if isinstance(ids, (int, long)):
@@ -135,7 +178,7 @@ class Product(ModelSQL, ModelView):
         if default is None:
             default = {}
         default = default.copy()
-        default['products'] = False
+        default['products'] = None
         new_ids = []
         for product in self.browse(ids):
             default['template'] = template_obj.copy(product.template.id)
